document.addEventListener('DOMContentLoaded', function() {
    const yearSelect = document.getElementById('birthYear');
    const monthSelect = document.getElementById('birthMonth');
    const daySelect = document.getElementById('birthDay');
    const hourSelect = document.getElementById('birthHour');
    const calculateBtn = document.getElementById('calculateBtn');
    const fortuneResult = document.getElementById('fortuneResult');

    // Populate year select (1900-2024)
    for (let year = 1900; year <= 2024; year++) {
        const option = document.createElement('option');
        option.value = year;
        option.textContent = year;
        yearSelect.appendChild(option);
    }

    // Populate month select (1-12)
    for (let month = 1; month <= 12; month++) {
        const option = document.createElement('option');
        option.value = month;
        option.textContent = month;
        monthSelect.appendChild(option);
    }

    // Populate day select (1-31)
    for (let day = 1; day <= 31; day++) {
        const option = document.createElement('option');
        option.value = day;
        option.textContent = day;
        daySelect.appendChild(option);
    }

    // Populate hour select (0-23)
    for (let hour = 0; hour <= 23; hour++) {
        const option = document.createElement('option');
        option.value = hour;
        option.textContent = hour.toString().padStart(2, '0') + ':00';
        hourSelect.appendChild(option);
    }

    const zodiacAnimals = ['Rat', 'Ox', 'Tiger', 'Rabbit', 'Dragon', 'Snake', 'Horse', 'Goat', 'Monkey', 'Rooster', 'Dog', 'Pig'];
    const elements = ['Wood', 'Fire', 'Earth', 'Metal', 'Water'];

    calculateBtn.addEventListener('click', function() {
        const year = parseInt(yearSelect.value);
        const month = parseInt(monthSelect.value);
        const day = parseInt(daySelect.value);
        const hour = parseInt(hourSelect.value);

        const zodiacIndex = (year - 1900) % 12;
        const elementIndex = Math.floor(((year - 1900) % 10) / 2);

        const zodiacAnimal = zodiacAnimals[zodiacIndex];
        const element = elements[elementIndex];

        const fortune = generateFortune(zodiacAnimal, element, month, day, hour);
        fortuneResult.innerHTML = fortune;
    });

    function generateFortune(zodiacAnimal, element, month, day, hour) {
        return `
            <h3>Your Cosmic Profile</h3>
            <p>Zodiac Animal: ${zodiacAnimal}</p>
            <p>Element: ${element}</p>
            <p>Lucky Numbers: ${Math.floor(Math.random() * 10)}, ${Math.floor(Math.random() * 10)}</p>
            <p>Fortune: Based on your ${element} ${zodiacAnimal} nature and the cosmic alignment of your birth time, 
            you possess unique characteristics that bring both opportunities and challenges. 
            This is a time for ${getFortuneTip(zodiacAnimal, element)}.</p>
        `;
    }

    function getFortuneTip(animal, element) {
        const tips = [
            'personal growth and self-discovery',
            'focusing on relationships and partnerships',
            'career advancement and professional development',
            'spiritual enlightenment and inner peace',
            'financial planning and material success'
        ];
        return tips[Math.floor(Math.random() * tips.length)];
    }
});